OC.L10N.register(
    "files_external",
    {
    "External storage" : "Malena memorilo",
    "Personal" : "Persona",
    "System" : "Sistemo",
    "Grant access" : "Doni alirpermeson",
    "Generate keys" : "Generi ŝlosilojn",
    "All users. Type to select user or group." : "Ĉiuj uzantoj. Tajpu por elekti uzanton aŭ grupon.",
    "(group)" : "(grupo)",
    "Admin defined" : "Difinita de administranto",
    "Saved" : "Konservita",
    "Username" : "Uzantonomo",
    "Password" : "Pasvorto",
    "Save" : "Konservi",
    "Invalid storage backend \"%s\"" : "Ne validas memormotoro \"%s”",
    "Not permitted to use backend \"%s\"" : "Ne permesatas uzi motoron “%s”",
    "Insufficient data: %s" : "Nesufiĉaj datumoj: %s",
    "%s" : "%s",
    "Access key" : "Alira ŝlosilo",
    "Secret key" : "Sekreta ŝlosilo",
    "App key" : "Aplikaĵa ŝlosilo",
    "App secret" : "Aplikaĵosekreto",
    "Client ID" : "Klientidentigilo",
    "Client secret" : "Klientosekreto",
    "API key" : "API-ŝlosilo",
    "Public key" : "Publika ŝlosilo",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Gastigonomo",
    "Port" : "Pordo",
    "Region" : "Regiono",
    "Enable SSL" : "Kapabligi SSL-on",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Fora subdosierujo",
    "Secure https://" : "Sekura https://",
    "Dropbox" : "Dropbox",
    "Local" : "Loka",
    "Location" : "Loko",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Gastigo",
    "Root" : "Radiko",
    "SFTP with secret key login" : "SFTP kun sekretoŝlosila ensaluto",
    "Share" : "Kunhavigi",
    "Username as share" : "Uzantonomo kiel kunhavigo",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Servonomo",
    "<b>Note:</b> " : "<b>Noto:</b>",
    "Name" : "Nomo",
    "Storage type" : "Memortipo",
    "Scope" : "Amplekso",
    "Enable encryption" : "Kapabligi ĉifradon",
    "Enable previews" : "Kapabligi antaŭvidojn",
    "Enable sharing" : "Kapabligi kunhavigadon",
    "Never" : "Neniam",
    "External Storage" : "Malena memorilo",
    "Folder name" : "Dosierujnomo",
    "Authentication" : "Aŭtentigo",
    "Configuration" : "Agordo",
    "Available for" : "Disponebla por",
    "Add storage" : "Aldoni memorilon",
    "Advanced settings" : "Altanivela agordo",
    "Delete" : "Forigi",
    "Allow users to mount the following external storage" : "Permesi uzantojn munti la jenajn malenajn memorilojn"
},
"nplurals=2; plural=(n != 1);");
